/*
	The canonical Internet Config interface is defined in Pascal.  These headers have
	not been thoroughly tested.  If there is a conflict between these headers and the
	Pascal interfaces, the Pascal should take precedence.
*/

/* ///////////////////////////////////////////////////////////////////////////////// */

#ifndef __ICKEYS__
#define __ICKEYS__

#ifndef __TYPES__
#include <Types.h>
#endif

#ifndef __ALIASES__
#include <Aliases.h>
#endif

/* ///////////////////////////////////////////////////////////////////////////////// */

#define kICRealName "RealName"	/* PString */
#define kICEmail "Email"	/* PString -- user@host.domain */
#define kICMailAccount "MailAccount"	/* PString -- user@host.domain */
#define kICMailPassword "MailPassword"	/* PString -- scrambled */
#define kICNewsAuthUsername "NewsAuthUsername"	/* PString -- host.domain */
#define kICNewsAuthPassword "NewsAuthPassword"	/* PString -- scrambled */
#define kICArchiePreferred "ArchiePreferred"	/* PString -- formatted */
#define kICArchieAll "ArchieAll"	/* STR# -- formatted */
#define kICUMichPreferred "UMichPreferred"	/* PString -- formatted */
#define kICUMichAll "UMichAll"	/* STR# -- formatted */
#define kICInfoMacPreferred "InfoMacPreferred"	/* PString -- formatted */
#define kICInfoMacAll "InfoMacAll"	/* STR# -- formatted */
#define kICPhHost "PhHost"	/* PString -- host.domain */
#define kICWhoisHost "WhoisHost"	/* PString -- host.domain */
#define kICFingerHost "FingerHost"	/* PString -- host.domain */
#define kICFTPHost "FTPHost"	/* PString -- host.domain */
#define kICTelnetHost "TelnetHost"	/* PString -- host.domain */
#define kICSMTPHost "SMTPHost"	/* PString -- host.domain */
#define kICNNTPHost "NNTPHost"	/* PString -- host.domain */
#define kICGopherHost "GopherHost"	/* PString -- host.domain */
#define kICWWWHomePage "WWWHomePage"	/* PString -- URL */
#define kICWAISGateway "WAISGateway"	/* PString -- no idea */
#define kICScreenFont "ScreenFont"	/* ICFontRecord */
#define kICPrinterFont "PrinterFont"	/* ICFontRecord */
#define kICTextCreator "TextCreator"	/* ICAppSpec */
#define kICBinaryTypeCreator "BinaryTypeCreator"	/* ICFileInfo */
#define kICDownloadFolder "DownloadFolder"	/* ICFileSpec */
#define kICSignature "Signature"	/* TEXT */
#define kICOrganization "Organization"	/* PString */
#define kICPlan "Plan"	/* TEXT */
#define kICQuotingString "QuotingString"	/* PString */
#define kICMailHeaders "MailHeaders"	/* TEXT */
#define kICNewsHeaders "NewsHeaders"	/* TEXT */
#define kICMapping "Mapping"	/* ICMapEntries */
#define kICCharacterSet "CharacterSet"	/* ICCharTable */
#define kICHelper "Helper"	/* ICAppSpec */
#define kICServices "Services"	/* ICServices */

#if defined(powerc) || defined (__powerc)
#pragma options align=mac68k
#endif

struct ICFontRecord {
	short size;
	Style face;
	Str255 font;
};
typedef struct ICFontRecord ICFontRecord, *ICFontRecordPtr, **ICFontRecordHandle;

struct ICCharTable {
	unsigned char net_to_mac[256];
	unsigned char mac_to_net[256];
};
typedef struct ICCharTable ICCharTable, *ICCharTablePtr, **ICCharTableHandle;

struct ICAppSpec {
	OSType fCreator;
	Str63 name;
};
typedef struct ICAppSpec ICAppSpec, *ICAppSpecPtr, **ICAppSpecHandle;

struct ICFileInfo {
	OSType fType;
	OSType fCreator;
	Str63 name;
};
typedef struct ICFileInfo ICFileInfo, *ICFileInfoPtr, **ICFileInfoHandle;

struct ICFileSpec {
	Str31 vol_name;
	long vol_creation_date;
	FSSpec fss;
	AliasRecord alias;
	/* plus extra data, aliasSize 0 means no alias manager present when
			ICFileSpecification was created */
};
typedef struct ICFileSpec ICFileSpec, *ICFileSpecPtr, **ICFileSpecHandle;

enum {
	ICfile_spec_header_size = sizeof(ICFileSpec) - sizeof(AliasRecord)
};

struct ICMapEntry {
	short total_length;
	short fixed_length;
	short version;
	OSType file_type;
	OSType file_creator;
	OSType post_creator;
	long flags;
	/* variable part starts here */
	Str255 extension;
	Str255 creator_app_name;
	Str255 post_app_name;
	Str255 MIME_type;
	Str255 entry_name;
};
typedef struct ICMapEntry ICMapEntry, *ICMapEntryPtr, **ICMapEntryHandle;

enum {
	ICmap_binary_bit = 0,						/* file should be transfered in binary as opposed to text mode */
	ICmap_binary_mask = 0x00000001,
	ICmap_resource_fork_bit = 1,		/* the resource fork of the file is significant */
	ICmap_resource_fork_mask = 0x00000002,
	ICmap_data_fork_bit = 2,				/* the data fork of the file is significant */
	ICmap_data_fork_mask = 0x00000004,
	ICmap_post_bit = 3,							/* post process using post fields */
	ICmap_post_mask = 0x00000008
};

struct ICServiceEntry {
	Str255 name;
	short port;
	short flags;
};
typedef struct ICServiceEntry ICServiceEntry, *ICServiceEntryPtr, **ICServiceEntryHandle;

struct ICServices {
	short count;
	ICServiceEntry services[1];
};
typedef struct ICServices ICServices, *ICServicesPtr, **ICServicesHandle;

enum {
	ICservices_tcp_bit = 0,
	ICservices_tcp_mask = 0x00000001,
	ICservices_udp_bit = 1,
	ICservices_udp_mask = 0x00000002
	/* both bits can be set, which means the service is both TCP and UDP, eg daytime */
};

#if defined(powerc) || defined(__powerc)
#pragma options align=reset
#endif

#endif
